@@ -1,3 +1,4 @@
+from django.contrib.postgres.fields import JSONField as PostgresJSONField
 from django.db import models
 from jsonfield.fields import JSONField
 
@@ -29,3 +30,11 @@ class CallableDefaultModel(models.Model):
 
     class Meta:
         app_label = 'jsonfield'
+
+
+class PostgresParallelModel(models.Model):
+    library_json = JSONField()
+    postgres_json = PostgresJSONField()
+
+    class Meta:
+        app_label = 'jsonfield'
