@@ -2,7 +2,7 @@ import json
 
 import django
 from django import forms
-from django.utils import six
+import six
 
 from .utils import default
 
