@@ -1,5 +1,7 @@
+#!/usr/bin/env python
 import os
 import sys
+import warnings
 import django
 
 BASE_PATH = os.path.dirname(__file__)
@@ -11,6 +13,9 @@ def main():
     You can play with a django model without a complete django app installation.
     http://www.djangosnippets.org/snippets/1044/
     """
+    warnings.filterwarnings("always", category=DeprecationWarning)
+    warnings.filterwarnings("always", category=PendingDeprecationWarning)
+
     os.environ["DJANGO_SETTINGS_MODULE"] = "django.conf.global_settings"
     from django.conf import global_settings
 
